<?php
new MaroyakaWebClapAdmin();

class MaroyakaWebClapAdmin extends MaroyakaWebClap {

	function __construct() {
		parent::__construct();
		add_action('admin_enqueue_scripts', array($this, 'admin_add_scripts'));
		add_action('admin_head', array($this, 'add_js'));
		add_action('admin_menu', array($this, 'plugin_menu'));
		add_action('admin_notices', array($this, 'config_notices'));
		add_action('admin_init', array($this, 'config_init'));

		add_action('add_meta_boxes', array($this, 'add_meta_box'));
		add_action('save_post', array($this, 'save_postdata'));
	}

	///////////////////////////////////////
	/* CSS&JavaScript登録 */
	///////////////////////////////////////
	public function admin_add_scripts() {
		global $wp_scripts;

		if (strpos($this->get_query('page'), 'mwc') === 0) {
			$ui = $wp_scripts->query('jquery-ui-core');

			wp_enqueue_style('jquery-ui-redmond', '//ajax.googleapis.com/ajax/libs/jqueryui/'. $ui->ver. '/themes/redmond/jquery-ui.min.css', false, null);
			wp_enqueue_style('mwc_style', MWC_PLUGIN_URL. '/css/mwc.css');
			wp_enqueue_style('admin-style', MWC_PLUGIN_URL. '/css/admin.css');
			wp_enqueue_style('thickbox');

			wp_enqueue_script('jquery');
			wp_enqueue_script('jquery-ui', '//ajax.googleapis.com/ajax/libs/jqueryui/'. $ui->ver. '/jquery-ui.min.js', $this->version, true);
			wp_enqueue_script('jquery-ui-i18n', '//ajax.googleapis.com/ajax/libs/jqueryui/'. $ui->ver. '/i18n/jquery-ui-i18n.min.js', $this->version, true);
			wp_enqueue_script('jquery-flot', MWC_PLUGIN_URL. '/js/jquery.flot.min.js', array('jquery'), $this->version, true);
			wp_enqueue_script('jquery-flot-time', MWC_PLUGIN_URL. '/js/jquery.flot.time.min.js', array('jquery-flot'), $this->version, true);
			wp_enqueue_script('admin-script', MWC_PLUGIN_URL. '/js/admin.js', array('jquery-ui'), $this->version, true);
			wp_enqueue_script('media-upload');
			wp_enqueue_script('thickbox');
		}
	}

	public function add_js() {
		echo '<!--[if IE]><script type="text/javascript" src="'. MWC_PLUGIN_URL .'/js/excanvas.min.js"></script><![endif]-->'. "\n";
	}

	///////////////////////////////////////
	/* 管理メニュー追加 */
	///////////////////////////////////////
	public function plugin_menu() {
		// add_submenu_page('index.php', 'まろやかWEB拍手 for WordPress', 'まろやかWEB拍手', MWC_CAPABILITY, 'maroyaka_webclap', 'mwc_clap_list');
		add_menu_page('まろやかWEB拍手 for WordPress','WEB拍手',  MWC_CAPABILITY, 'mwc', array($this, 'mwc_clap_list'), 'dashicons-heart', 43);
		add_submenu_page('mwc', '拍手一覧 - まろやかWEB拍手 for WordPress', '拍手一覧', MWC_CAPABILITY, 'mwc');
		add_submenu_page('mwc', '拍手ページ一覧 - まろやかWEB拍手 for WordPress', '拍手ページ一覧', MWC_CAPABILITY,  'mwc_id_list', array($this, 'mwc_id_list'));
		add_submenu_page('mwc', '集計 - まろやかWEB拍手 for WordPress', '集計', MWC_CAPABILITY, 'mwc_graph', array($this, 'mwc_graph'));
		add_submenu_page('mwc', '設定 - まろやかWEB拍手 for WordPress', '設定', MWC_CAPABILITY, 'mwc_config', array($this, 'mwc_config'));
	}

	///////////////////////////////////////
	/* カスタムフィールド追加 */
	///////////////////////////////////////
	public function add_meta_box() {
		add_meta_box('mwc_meta_box', 'WEB拍手', array($this, 'mwc_inner_custom_box'), 'post');
		add_meta_box('mwc_meta_box', 'WEB拍手', array($this, 'mwc_inner_custom_box'), 'page');
	}

	///////////////////////////////////////
	/* カスタムフィールド表示 */
	///////////////////////////////////////
	public function mwc_inner_custom_box() {
		wp_nonce_field(wp_create_nonce(MWC_PLUGIN), 'mwc_custom_box');
		$deny_btn = get_post_meta(get_the_ID(), 'mwc_deny_btn', true);
		echo '<label><input type="checkbox" name="mwc_deny_btn" value="1"'. checked($deny_btn, 1, false). ' /> WEB拍手ボタンを表示しない</label>';
	}

	///////////////////////////////////////
	/* カスタムフィールド保存 */
	///////////////////////////////////////
	public function save_postdata($post_id) {
		if (getenv('REQUEST_METHOD') !== 'POST') return $post_id;

		// nonceチェック
		if (isset($_POST['mwc_custom_box']) && !check_admin_referer(wp_create_nonce(MWC_PLUGIN), 'mwc_custom_box')) return $post_id;

		// 自動保存ルーチンチェック
		if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) return $post_id;

		// パーミッションチェック
		if (isset($_POST['post_type'])) {
			if ($_POST['post_type'] == 'page' && !current_user_can('edit_page', $post_id)) return $post_id;
			if ($_POST['post_type'] == 'post' && !current_user_can('edit_post', $post_id)) return $post_id;
		}

		// データ保存
		$deny_btn = (isset($_POST['mwc_deny_btn'])) ? 1 : 0;
		update_post_meta($post_id, 'mwc_deny_btn', $deny_btn);
	}

	///////////////////////////////////////
	/* 集計 */
	///////////////////////////////////////
	public function mwc_graph() {
		$viewdate = $this->get_query('viewdate', date_i18n("Ymd"));
		$viewtime = strtotime($viewdate);

		/* == 時間毎 ====================================================== */
		// 拍手数

		$sql = "SELECT COUNT(*) AS count, DATE_FORMAT(clp.timestamp, '%%Y/%%m/%%d %%H:00') AS time".
						" FROM ". $this->prefix. MWC_DB_TABLE_CLAP. " AS clp".
						" WHERE DATE_FORMAT(clp.timestamp, '%%Y%%m%%d') = %s".
						" GROUP BY time".
						" ORDER BY time ASC";
		$data = $this->db->get_results($this->db->prepare($sql, $viewdate), ARRAY_A);
		/* flotの表示調整のために空データを追加する */
		array_unshift($data, array('time' => date_i18n("Y/m/d 00:00", $viewtime), 'count' => 'null'));
		array_push($data, array('time' => date_i18n("Y/m/d 23:00", $viewtime), 'count' => 'null'));
		/* --- */
		$clap_time_json =$this->json_format($data);

		// メッセージ
		$sql = "SELECT COUNT(*) AS count, DATE_FORMAT(clp.timestamp, '%%Y/%%m/%%d %%H:00') AS time".
						" FROM ". $this->prefix. MWC_DB_TABLE_CLAP. " AS clp".
						" LEFT JOIN ". $this->prefix. MWC_DB_TABLE_MESSAGES. " AS msg".
							" ON clp.id = msg.clap_id".
						" WHERE DATE_FORMAT(clp.timestamp, '%%Y%%m%%d') = %s".
							" AND msg.message != ''".
						" GROUP BY time".
						" ORDER BY time ASC";
		$data = $this->db->get_results($this->db->prepare($sql, $viewdate), ARRAY_A);
		/* flotの表示調整のために空データを追加する */
		array_unshift($data, array('time' => date_i18n("Y/m/d 00:00", $viewtime), 'count' => 'null'));
		array_push($data, array('time' => date_i18n("Y/m/d 23:00", $viewtime), 'count' => 'null'));
		/* --- */
		$msg_time_json =$this->json_format($data);
		/* ============================================================ */

		/* == 日次 ====================================================== */
		$viewmonth = date_i18n("Ym", $viewtime);
		// 拍手数
		$sql = "SELECT COUNT(*) AS count, DATE_FORMAT(clp.timestamp, '%%Y/%%m/%%d 00:00') AS time".
						" FROM ". $this->prefix. MWC_DB_TABLE_CLAP. " AS clp".
						" WHERE DATE_FORMAT(clp.timestamp, '%%Y%%m') = %s".
						" GROUP BY time".
						" ORDER BY time ASC";
		$clap_day_json =$this->json_format($this->db->get_results($this->db->prepare($sql, $viewmonth), ARRAY_A));

		// メッセージ
		$sql = "SELECT COUNT(*) AS count, DATE_FORMAT(clp.timestamp, '%%Y/%%m/%%d 00:00') AS time".
						" FROM ". $this->prefix. MWC_DB_TABLE_CLAP. " AS clp".
						" LEFT JOIN ". $this->prefix. MWC_DB_TABLE_MESSAGES. " AS msg".
							" ON clp.id = msg.clap_id".
						" WHERE DATE_FORMAT(clp.timestamp, '%%Y%%m') = %s".
							" AND msg.message != ''".
						" GROUP BY time".
						" ORDER BY time ASC";
		$msg_day_json =$this->json_format($this->db->get_results($this->db->prepare($sql, $viewmonth), ARRAY_A));
		/* ============================================================ */

		/* == 月次 ====================================================== */
		$viewyear = date_i18n("Y", $viewtime);
		// 拍手数
		$sql = "SELECT COUNT(*) AS count, DATE_FORMAT(clp.timestamp, '%%Y/%%m/01 00:00') AS time".
						" FROM ". $this->prefix. MWC_DB_TABLE_CLAP. " AS clp".
						" WHERE DATE_FORMAT(clp.timestamp, '%%Y') = %s".
						" GROUP BY DATE_FORMAT(clp.timestamp, '%%Y%%m')".
						" ORDER BY time ASC";
		$clap_month_json =$this->json_format($this->db->get_results($this->db->prepare($sql, $viewyear), ARRAY_A));

		// メッセージ
		$sql = "SELECT COUNT(*) AS count, DATE_FORMAT(clp.timestamp, '%%Y/%%m/01 00:00') AS time".
						" FROM ". $this->prefix. MWC_DB_TABLE_CLAP. " AS clp".
						" LEFT JOIN ". $this->prefix. MWC_DB_TABLE_MESSAGES. " AS msg".
							" ON clp.id = msg.clap_id".
						" WHERE DATE_FORMAT(clp.timestamp, '%%Y') = %s".
							" AND msg.message != ''".
						" GROUP BY DATE_FORMAT(clp.timestamp, '%%Y%%m')".
						" ORDER BY time ASC";
		$msg_month_json =$this->json_format($this->db->get_results($this->db->prepare($sql, $viewyear), ARRAY_A));
		/* ============================================================ */

		?>
		<div class="wrap">
			<h2>集計</h2>
			<hr>
			<h3>	時間毎 <small>（<?php echo date_i18n("Y年m月d日", $viewtime); ?>）</small></h3>
			<a href="<?php echo esc_html(add_query_arg(array('viewdate' => date_i18n("Ymd", strtotime($viewdate. " -1 day"))))); ?>" class="button">&laquo; 前日</a>
			<?php if (date_i18n("Y-m-d", $viewtime) == date_i18n("Y-m-d")) : ?>
				<a  class="button disabled">翌日 &raquo;</a>
			<?php else : ?>
				<a href="<?php echo esc_html(add_query_arg(array('viewdate' => date_i18n("Ymd", strtotime($viewdate. " +1 day"))))); ?>" class="button">翌日 &raquo;</a>
			<?php endif; ?>
			<div data-target="time-graph" class="mwc-graph"></div>
			<hr>
			<h3>	日次 <small>（<?php echo date_i18n("Y年m月", $viewtime); ?>）</small></h3>
			<a href="<?php echo esc_html(add_query_arg(array('viewdate' => date_i18n("Ym01", strtotime($viewdate. " -1 month"))))); ?>" class="button">&laquo; 前月</a>
			<?php if (date_i18n("Y-m", $viewtime) == date_i18n("Y-m")) : ?>
				<a  class="button disabled">翌月 &raquo;</a>
			<?php else : ?>
				<a href="<?php echo esc_html(add_query_arg(array('viewdate' => date_i18n("Ym01", strtotime($viewdate. " +1 month"))))); ?>" class="button">翌月 &raquo;</a>
			<?php endif; ?>
			<div data-target="day-graph" class="mwc-graph"></div>
			<hr>
			<h3>	月次 <small>（<?php echo date_i18n("Y年", $viewtime); ?>）</small></h3>
			<a href="<?php echo esc_html(add_query_arg(array('viewdate' => date_i18n("Y0101", strtotime($viewdate. " -1 year"))))); ?>" class="button">&laquo; 前年</a>
			<?php if (date_i18n("Y", $viewtime) == date_i18n("Y")) : ?>
				<a  class="button disabled">翌年 &raquo;</a>
			<?php else : ?>
				<a href="<?php echo esc_html(add_query_arg(array('viewdate' => date_i18n("Y0101", strtotime($viewdate. " +1 year"))))); ?>" class="button">翌年 &raquo;</a>
			<?php endif; ?>
			<div data-target="month-graph" class="mwc-graph"></div>
		</div>
		<script type="text/javascript">
		jQuery(document).ready(function($) {
			var date = new Date();
			var wsm = ($(window).width() > 768) ? false : true;

			var option1_1 = {
				label: "拍手数",
				bars: { align: "right" },
				color: "#ED4040"
			};
			var option1_2 = {
				label: "メッセージ数",
				bars: { align: "left" },
				color: "#3D75E5"
			};

			var option2 = {
				legend: { position : "nw" },
				grid: { 
					hoverable: true, 
					borderWidth: 1,
					borderColor: "#CCCCCC"
				},
				yaxis: { min: 0 }
			};

			// 時間毎
			$.plot('div[data-target="time-graph"]', [$.extend(<?php echo $clap_time_json; ?>, option1_1), $.extend(<?php echo $msg_time_json; ?>, option1_2)], $.extend({
				series: {
					bars: { show: true },
				},
				bars: {
					barWidth: 60*60*1000 / 4,
					show: true
				},
				xaxis: {
					mode: "time",
					timeformat: '<span style="white-space: nowrap;">%H時</span>',
					tickSize: [(wsm ? 3 : 1), "hour"],
					twelveHourClock: true
					// ,min: new Date(date.getFullYear(), date.getMonth(), date.getDate(), 0, 0, 0).getTime() - offset,
					// max: new Date(date.getFullYear(), date.getMonth(), date.getDate(), 23, 59, 59).getTime() - offset
				}
			}, option2));

			// 日次
			$.plot('div[data-target="day-graph"]', [$.extend(<?php echo $clap_day_json; ?>, option1_1), $.extend(<?php echo $msg_day_json; ?>, option1_2)], $.extend({
				series: {
					lines: { show: true, fill: true },
					points: { show: true }
				},
				xaxis: {
					mode: "time",
					timeformat: '<span style="white-space: nowrap;">%d日</span>',
					tickSize: [(wsm ? 3 : 1), "day"],
					min: Date.UTC(date.getFullYear(), date.getMonth(), 1, 0, 0),
					max: Date.UTC(date.getFullYear(), date.getMonth() + 1, 0, 0, 0)
				}
			}, option2));

			// 月次
			$.plot('div[data-target="month-graph"]', [$.extend(<?php echo $clap_month_json; ?>, option1_1), $.extend(<?php echo $msg_month_json; ?>, option1_2)], $.extend({
				series: {
					lines: { show: true, fill: true },
					points: { show: true }
				},
				xaxis: {
					mode: "time",
					timeformat: "%m月",
					tickSize: [(wsm ? 2 : 1), "month"],
					min: Date.UTC(date.getFullYear(), 0, 1, 0, 0),
					max: Date.UTC(date.getFullYear() + 1, 0, 0, 0, 0)
				}
			}, option2));

			// ツールチップ
			$('<div id="mwc-graph-tooltip" class="mwc-graph-tooltip"></div>').appendTo("body");
			$('.mwc-graph').bind("plothover", function(event, pos, item) {
				if (item) {
					var x = item.datapoint[0].toFixed(2),
							y = item.datapoint[1].toFixed(2);

						$("#mwc-graph-tooltip").html(item.series.label + "：<strong>" + item.datapoint[1] + "</strong>")
						.css({top: item.pageY - 40, left: item.pageX - 30})
						.fadeIn(200);
				} else {
					$("#mwc-graph-tooltip").hide();
				}
			});
		});
		</script>
		<?php
	}

	///////////////////////////////////////
	/* JSON形成 */
	///////////////////////////////////////
	private function json_format($data) {
		$json = array();
		foreach ($data as $val) {
			$json[] = '[ '. (strtotime($val['time']. " UTC") * 1000). ', '. $val['count']. ' ]';
		}
		return '{ data: ['. implode(",", $json). '] }';
	}

	///////////////////////////////////////
	/* 設定 */
	///////////////////////////////////////
	public function config_notices() {
	?>
		<?php if ($this->get_query('page') == 'mwc_config') : ?>
			<?php if ($messages = get_transient('mwc-config-errors')): ?>
				<div class="message error">
					<ul>
						<?php foreach( $messages as $message ): ?>
							<li><?php echo esc_html($message); ?></li>
						<?php endforeach; ?>
					</ul>
				</div>
			<?php endif; ?>
			<?php if ($messages = get_transient('mwc-config-updateds')): ?>
				<div class="message updated">
					<ul>
						<?php foreach($messages as $message): ?>
							<li><?php echo esc_html($message); ?></li>
						<?php endforeach; ?>
					</ul>
				</div>
			<?php endif; ?>
		<?php endif; ?>
	<?php
	}

	public function config_init() {
		if (getenv('REQUEST_METHOD') !== 'POST' || !isset($_POST['mwc_action'])) return;

		$e = new WP_Error();

		switch ($_POST['mwc_action']) {
			case 'config':
				// 設定保存

				check_admin_referer('mwc_config');

				$max_claping = esc_attr($this->get_post('max_claping'));
				if (!is_numeric($max_claping)) {
					$e->add('error', '連続拍手限度数は半角数字で入力してください。');
				}
				$reclap_time = esc_attr($this->get_post('reclap_time'));
				if (!is_numeric($reclap_time)) {
					$e->add('error', '再拍手可能時間は半角数字で入力してください。');
				}
				$mailaddress = esc_attr($this->get_post('mailaddress'));
				if (!empty($mailaddress) && !is_email($mailaddress)) {
					$e->add('error', '通知先メールアドレスが不正です。');
				}

				if ($e->get_error_code()) {
					set_transient('mwc-config-errors', $e->get_error_messages('error'), 3);
				} else {
					$set_phrases = array();
					foreach ($this->get_post('set_phrases', array()) as $set_phrase) $set_phrases[] = esc_attr($set_phrase);
					$deny_ips = array();
					foreach ($this->get_post('deny_ips', array()) as $ip) $deny_ips[] = esc_attr($ip);

					$mwc_config = array(
						'btn_locate_single' => $this->get_post('btn_locate_single'),
						'btn_locate_page' => $this->get_post('btn_locate_page'),
						'btn_locate_loop' => $this->get_post('btn_locate_loop'),
						'btn_align' => $this->get_post('btn_align'),
						'btn_text' => $this->get_post('btn_text'),
						'btn_type' => $this->get_post('btn_type'),
						'btn_color' => $this->get_post('btn_color'),
						'btn_count_view' => $this->get_post('btn_count_view'),
						'max_claping' => $max_claping,
						'max_clap_decision' => $this->get_post('max_clap_decision'),
						'reclap_time' => $reclap_time,
						'thanks_balloon' => $this->get_post('thanks_balloon'),
						'thanks_msg' => esc_attr($this->get_post('thanks_msg')),
						'thanks_img_val' => esc_attr($this->get_post('thanks_img_val')),
						'name_input' => $this->get_post('name_input'),
						'set_phrases_select' => $this->get_post('set_phrases_select'),
						'message_input' => $this->get_post('message_input'),
						'set_phrases' => $set_phrases,
						'deny_ips' => $deny_ips,
						'mail_notice_name' => $this->get_post('mail_notice_name'),
						'mail_notice_sp' => $this->get_post('mail_notice_sp'),
						'mail_notice_msg' => $this->get_post('mail_notice_msg'),
						'mail_clap_report' => $this->get_post('mail_clap_report'),
						'mailaddress' => $mailaddress,
						'db_version' => $this->get_option('db_version')
					);
					update_option('mwc_config', $mwc_config);

					// cron
					MaroyakaWebClapCron::add_schedule_event();

					$e->add('updated', '正常に保存が完了しました');
					set_transient('mwc-config-updateds', $e->get_error_messages('updated'), 5);
				}

				wp_safe_redirect(menu_page_url('mwc_config', false));
				break;
			
			// case 'delete':
			// 	// 削除実行

			// 	check_admin_referer('bulk-clap_list');

			// 	if (empty($_POST['clap_id'])) {
			// 		$e->add('error', '削除対象を選択されていません');
			// 	}

			// 	if (!$e->get_error_code()) {
			// 		$ids = implode( ',', array_map( 'absint', $_POST['clap_id'] ) );
			// 		$result = $this->db->query( "DELETE FROM ". MWC_DB_TABLE_CLAP. " WHERE id IN($ids)" );

			// 		if (!$result) {
			// 			$e->add('error', '削除できませんでした');
			// 		}
			// 	}

			// 	if ($e->get_error_code()) {
			// 		set_transient('mwc-errors', $e->get_error_messages('error'), 3);
			// 	} else {
			// 		set_transient('mwc-updated', '削除しました', 3);
			// 	}

			// 	wp_safe_redirect(menu_page_url('mwc', false));

			// 	break;
		}
		exit();
	}

	public function mwc_config() {
		?>
		<div class="wrap">
			<h2>設定</h2>
			<form method="post" action="">
				<?php wp_nonce_field('mwc_config'); ?>
				<input type="hidden" name="mwc_action" value="config" />
				<table class="form-table" id="mwc-option-form">
					<tr valign="top">
						<th scope="row">拍手ボタン設置ページ</th>
						<td>
							<fieldset>
								<legend class="screen-reader-text"><span>拍手ボタン設置ページ</span></legend>
								<label for="btn_locate_single"><input name="btn_locate_single" type="checkbox" id="btn_locate_single" value="1"<?php checked($this->get_option('btn_locate_single'), 1); ?> /> 投稿ページ</label><br />
								<label for="btn_locate_page"><input name="btn_locate_page" type="checkbox" id="btn_locate_page" value="1"<?php checked($this->get_option('btn_locate_page'), 1); ?> /> 固定ページ</label><br />
								<label for="btn_locate_loop"><input name="btn_locate_loop" type="checkbox" id="btn_locate_loop" value="1"<?php checked($this->get_option('btn_locate_loop'), 1); ?> /> 記事一覧（メインループ内）</label>
							</fieldset>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">ボタン表示位置</th>
						<td>
							<select name="btn_align">
								<option value="left"<?php selected($this->get_option('btn_align'), 'left'); ?>>左</option>
								<option value="center"<?php selected($this->get_option('btn_align'), 'center'); ?>>中央</option>
								<option value="right"<?php selected($this->get_option('btn_align'), 'right'); ?>>右</option>
							</select>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">拍手ボタンテキスト</th>
						<td>
							<input name="btn_text" type="text" id="btn_text" value="<?php echo $this->get_option('btn_text'); ?>" />
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">ボタンタイプ</th>
						<td>
								<div class="maroyaka-webclap">
									<label for="btn_type_normal"><input name="btn_type" type="radio" id="btn_type_normal" value="normal"<?php checked($this->get_option('btn_type'), 'normal'); ?> />
										<button type="button" class="btn btn-xs btn-default">WEB拍手 <span class="count">0</span></button></label><br />
									<label for="btn_type_balloon"><input name="btn_type" type="radio" id="btn_type_balloon" value="balloon"<?php checked($this->get_option('btn_type'), 'balloon'); ?> />
										<button type="button" class="btn btn-xs btn-default">WEB拍手</button><span class="balloon"><span class="inner"><span class="count">0</span></span></span></label><br />
								</div>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">ボタンカラー</th>
						<td>
								<div class="maroyaka-webclap">
									<label for="btn_color_default"><input name="btn_color" type="radio" id="btn_color_default" value="default"<?php checked($this->get_option('btn_color'), 'default'); ?> /> <button type="button" class="btn btn-xs btn-default">WEB拍手 <span class="count">0</span></button></label><br />
									<label for="btn_color_primary"><input name="btn_color" type="radio" id="btn_color_primary" value="primary"<?php checked($this->get_option('btn_color'), 'primary'); ?> /> <button type="button" class="btn btn-xs btn-primary">WEB拍手 <span class="count">0</span></button></label><br />
									<label for="btn_color_success"><input name="btn_color" type="radio" id="btn_color_success" value="success"<?php checked($this->get_option('btn_color'), 'success'); ?> /> <button type="button" class="btn btn-xs btn-success">WEB拍手 <span class="count">0</span></button></label><br />
									<label for="btn_color_info"><input name="btn_color" type="radio" id="btn_color_info" value="info"<?php checked($this->get_option('btn_color'), 'info'); ?> /> <button type="button" class="btn btn-xs btn-info">WEB拍手 <span class="count">0</span></button></label><br />
									<label for="btn_color_warning"><input name="btn_color" type="radio" id="btn_color_warning" value="warning"<?php checked($this->get_option('btn_color'), 'warning'); ?> /> <button type="button" class="btn btn-xs btn-warning">WEB拍手 <span class="count">0</span></button></label><br />
									<label for="btn_color_danger"><input name="btn_color" type="radio" id="btn_color_danger" value="danger"<?php checked($this->get_option('btn_color'), 'danger'); ?> /> <button type="button" class="btn btn-xs btn-danger">WEB拍手 <span class="count">0</span></button></label><br />
								</div>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">拍手数の表示</th>
						<td>
								<label for="btn_count_view"><input name="btn_count_view" type="checkbox" id="btn_count_view" value="1"<?php checked($this->get_option('btn_count_view'), 1); ?> /> 拍手数を表示する</label>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row"><label for="max_claping">連続拍手限度数</label></th>
						<td>
							<fieldset>
								<legend class="screen-reader-text"><span>連続拍手限度数</span></legend>
								<input name="max_claping" type="text" class="small-text" id="max_claping" value="<?php echo $this->get_option('max_claping'); ?>" />
								<p class="description">ひとつの拍手ボタンに対して連続何回まで拍手可能にするかを設定できます。<br />0を設定すると無制限になります。</p>
							</fieldset>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row"><label for="max_clap_decision">連続拍手判定方法</label></th>
						<td>
							<select name="max_clap_decision" id="max_clap_decision">
								<option value="ip"<?php selected($this->get_option('max_clap_decision'), 'ip'); ?>>IPアドレス</option>
								<option value="cookie"<?php selected($this->get_option('max_clap_decision'), 'cookie'); ?>>Cookie</option>
								<option value="ip_cookie"<?php selected($this->get_option('max_clap_decision'), 'ip_cookie'); ?>>IPアドレス+Cookie</option>
							</select>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row"><label for="reclap_time">再拍手可能時間</label></th>
						<td>
							<input name="reclap_time" type="text" class="small-text" id="reclap_time" value="<?php echo $this->get_option('reclap_time'); ?>" />時間
						</td>
					</tr>
					<tr valign="top">
						<th scope="row"><label for="thanks_balloon">拍手後吹き出し</label></th>
						<td>
							<select name="thanks_balloon" id="thanks_balloon">
								<option value="1"<?php selected($this->get_option('thanks_balloon'), 1); ?>>表示する</option>
								<option value="0"<?php selected($this->get_option('thanks_balloon'), 0); ?>>表示しない</option>
							</select>
							<p class="description">「表示する」にすると拍手後にメッセージが送信できるようになります。</p>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row"><label for="thanks_msg">拍手後メッセージ</label></th>
						<td>
							<textarea rows="6" cols="40" name="thanks_msg" id="thanks_msg"><?php echo $this->get_option('thanks_msg'); ?></textarea>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row"><label for="thanks_img">拍手後お礼絵</label></th>
						<td>
							<?php
							$thanks_img_val = $this->get_option('thanks_img_val');
							if ( empty( $thanks_img_val ) ) : ?>
								<img class="thanks_img" src="data:image/gif;base64,R0lGODlhAQABAIAAAAAAAAAAACH5BAEAAAAALAAAAAABAAEAAAICRAEAOw%3D%3D" />
							<?php else : ?>
								<img class="thanks_img" src="<?php echo $this->get_option('thanks_img_val'); ?>" />
							<?php endif; ?>
							<input class="thanks_img_add_btn button" type="button" value="画像指定" />
							<input class="thanks_img_del_btn button" type="button" value="削除" />
							<input class="thanks_img_val" type="hidden" name="thanks_img_val" value="" />
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">入力欄</th>
						<td>
							<fieldset>
								<legend class="screen-reader-text"><span>入力欄</span></legend>
								<label for="name_input"><input name="name_input" type="checkbox" id="name_input" value="1"<?php checked($this->get_option('name_input'), 1); ?> /> 名前入力欄を設ける</label><br />
								<label for="set_phrases_select"><input name="set_phrases_select" type="checkbox" id="set_phrases_select" value="1"<?php checked($this->get_option('set_phrases_select'), 1); ?> /> 定型文選択欄を設ける</label><br />
								<label for="message_input"><input name="message_input" type="checkbox" id="message_input" value="1"<?php checked($this->get_option('message_input'), 1); ?> /> メッセージ入力欄を設ける</label>
							</fieldset>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">定型文</th>
						<td>
							<fieldset>
								<legend class="screen-reader-text"><span>定型文</span></legend>
								<div class="input-custom-field" data-field-name="set_phrases">
									<?php $set_phrases = $this->get_option('set_phrases'); ?>
									<?php foreach($set_phrases as $set_phrase): ?>
										<input name="set_phrases[]" type="text" value="<?php echo $set_phrase; ?>" class="regular-text" />
									<?php endforeach; ?>
								</div>
								<button type="button" class="button input-action" data-action="add">+ 追加</button>
								<button type="button" class="button input-action" data-action="remove">- 削除</button>
							</fieldset>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">IPアクセス制限</th>
						<td>
							<fieldset>
								<legend class="screen-reader-text"><span>IPアクセス制限</span></legend>
								<div class="input-custom-field" data-field-name="deny_ips">
									<?php $deny_ips = $this->get_option('deny_ips'); ?>
									<?php foreach($deny_ips as $ip): ?>
										<input name="deny_ips[]" type="text" value="<?php echo $ip; ?>" class="regular-text" style="display: block;" />
									<?php endforeach; ?>
								</div>
								<button type="button" class="button input-action" data-action="add">+ 追加</button>
								<button type="button" class="button input-action" data-action="remove">- 削除</button>
							</fieldset>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">メール通知フラグ</th>
						<td>
							<fieldset>
								<legend class="screen-reader-text"><span>メール通知フラグ</span></legend>
								<label for="mail_notice_name"><input name="mail_notice_name" type="checkbox" id="mail_notice_name" value="1"<?php checked($this->get_option('mail_notice_name'), 1); ?> /> 名前があったらメール通知する</label><br />
								<label for="mail_notice_sp"><input name="mail_notice_sp" type="checkbox" id="mail_notice_sp" value="1"<?php checked($this->get_option('mail_notice_sp'), 1); ?> /> 定型文があったらメール通知する</label><br />
								<label for="mail_notice_msg"><input name="mail_notice_msg" type="checkbox" id="mail_notice_msg" value="1"<?php checked($this->get_option('mail_notice_msg'), 1); ?> /> メッセージがあったらメール通知する</label><br />
							</fieldset>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row">拍手レポート</th>
						<td>
							<fieldset>
								<legend class="screen-reader-text"><span>拍手レポート</span></legend>
								<label for="mail_clap_report"><input name="mail_clap_report" type="checkbox" id="mail_clap_report" value="1"<?php checked($this->get_option('mail_clap_report'), 1); ?> /> 日毎に拍手レポート送信する</label><br />
							</fieldset>
						</td>
					</tr>
					<tr valign="top">
						<th scope="row"><label for="mailaddress">通知先メールアドレス</label></th>
						<td>
							<input name="mailaddress" type="text" class="regular-text" id="mailaddress" value="<?php echo $this->get_option('mailaddress'); ?>" />
							<p class="description">未入力の場合、管理者メールアドレスが適用されます。</p>
						</td>
					</tr>
				</table>
				<p class="submit"><input type="submit" name="Submit" class="button-primary" value="保存" /></p>
			</form>
		</div>
		<?php
	}

	///////////////////////////////////////
	/* 拍手一覧 */
	///////////////////////////////////////
	public function mwc_clap_list() {
		$wp_list_table = new MWC_Clap_List_Table();

		$sql = "SELECT *".
						" FROM " . $this->prefix. MWC_DB_TABLE_CLAP. " AS cl".
						" WHERE";

		// 日付指定
		$specify = '';
		$today = date_i18n("Y-m-d");
		$sdate = $today;

		switch (true) {
			case isset($_GET['month']): $specify = ' month'; break;
			case isset($_GET['week']): $specify = ' week'; break;
			case isset($_GET['yesterday']): $specify = ' yesterday'; break;
			case isset($_GET['today']): $specify = ' today'; break;
		}

		if (empty($specify) && isset($_GET['date_from']) && isset($_GET['date_to'])) {
			$from = (isset($_GET['date_from']) && preg_match("/[0-9]{4}-[0-9]{2}-[0-9]{2}/", $_GET['date_from'])) ? $_GET['date_from'] : $today;
			$to = (isset($_GET['date_to']) && preg_match("/[0-9]{4}-[0-9]{2}-[0-9]{2}/", $_GET['date_to'])) ? $_GET['date_to'] : $today;
			$sql .= " cl.timestamp >= '". $from. " 00:00:00' AND cl.timestamp <= '". $to. " 23:59:59'";
		} else {
			if (!empty($specify)) {
				$sdate = date_i18n("Y-m-d", strtotime($today. ' -1 '. $specify));
			}
			$sql .= " cl.timestamp >= '". $sdate. " 00:00:00'";
			$from = $sdate;
			$to = $today;
		}

		$sql .= " ORDER BY cl.id DESC";

		$sql = "SELECT *, COUNT(*) AS clap".
						" FROM (". $sql. ") AS gcl".
						" LEFT JOIN ". $this->prefix. MWC_DB_TABLE_MESSAGES. " AS ms".
							" ON gcl.id = ms.clap_id".
						" LEFT JOIN ". $this->prefix. MWC_DB_TABLE_ID. " AS cid".
							" ON gcl.post_id = cid.post_id".
						" GROUP BY gcl.ip, gcl.post_id";

		if ($this->get_option('message_input') != 1) {
			$wp_list_table->add_hidden_columns('message');
		} else {
			$sql .= ", ms.message";
		}
		if ($this->get_option('set_phrases_select') != 1) {
			$wp_list_table->add_hidden_columns('set_phrases');
		} else {
			$sql .= ", ms.set_phrases";
		}
		if ($this->get_option('name_input') != 1) {
			$wp_list_table->add_hidden_columns('name');
		} else {
			$sql .= ", ms.name";
		}

		$cog = array();

		// メッセージ有りのみ
		if (isset($_GET['msg_only'])) {
			$msg_only = esc_attr($_GET['msg_only']);
			$cog['list_clap_msg_only'] = $msg_only;
		} else {
			$msg_only = $this->get_option('list_clap_msg_only');
		}
		if (!empty($msg_only)) {
			$sql .= " HAVING ms.message != ''";
		}

		// アイキャッチ表示
		if (isset($_GET['view_eyecatch'])) {
			$view_eyecatch = esc_attr($_GET['view_eyecatch']);
			$cog['list_clap_view_eyecatch'] = $view_eyecatch;
		} else {
			$view_eyecatch = $this->get_option('list_clap_view_eyecatch');
		}
		if (!empty($view_eyecatch)) {
			$wp_list_table->view_eyecatch = true;
		}

		// 記事ID表示
		if (isset($_GET['view_post_id'])) {
			$view_post_id = esc_attr($_GET['view_post_id']);
			$cog['list_clap_view_post_id'] = $view_post_id;
		} else {
			$view_post_id = $this->get_option('list_clap_view_post_id');
		}
		if (!empty($view_post_id)) {
			$wp_list_table->view_post_id = true;
		}

		// 表示設定保存
		if (!empty($cog)) {
			update_option('mwc_config', array_merge($this->pnop, $cog));
		}

		$wp_list_table->query = $sql;
		$wp_list_table->prepare_items();

		$total_clap = 0;
		foreach ($wp_list_table->items as $item) {
			$total_clap += $item->clap;
		}

		?>
		<div class="wrap">
			<h2>拍手一覧</h2>
			<form action="" method="get" name="mwc-clap-table-tool">
				<input type="hidden" name="page" value="mwc" />
				<ul class="mwc-clap-table-tool">
					<li>
						<button type="submit" name="month" class="button<?php if (isset($_GET['month'])) echo ' active'; ?>">一ヶ月</button>
						<button type="submit" name="week" class="button<?php if (isset($_GET['week'])) echo ' active'; ?>">一週</button>
						<button type="submit" name="yesterday" class="button<?php if (isset($_GET['yesterday'])) echo ' active'; ?>">昨日</button>
						<button type="submit" name="today" class="button<?php if (isset($_GET['today'])) echo ' active'; ?>">今日</button>
					</li>
					<li>
						<input type="text" name="date_from" value="<?php echo $from; ?>" class="datepicker" id="datepicker-from" />
						～
						<input type="text" name="date_to" value="<?php echo $to; ?>" class="datepicker" id="datepicker-to" />
						<button type="submit" class="button">表示</button>
					</li>
					<?php if ($this->get_option('message_input') == 1) : ?>
						<li>
							<input type="hidden" name="msg_only" value="0" />
							<label><input type="checkbox" name="msg_only" value="1"<?php checked($msg_only, 1); ?> /> メッセージ有りのみ表示する</label>
						</li>
					<?php endif; ?>
					<li>
						<input type="hidden" name="view_eyecatch" value="0" />
						<label><input type="checkbox" name="view_eyecatch" value="1"<?php checked($view_eyecatch, 1); ?> /> アイキャッチ画像を表示する</label>
					</li>
					<li>
						<input type="hidden" name="view_post_id" value="0" />
						<label><input type="checkbox" name="view_post_id" value="1"<?php checked($view_post_id, 1); ?> /> 記事IDを表示する</label>
					</li>
				</ul>
			</form>
			<hr />
			総拍手数：<span class="clap_count"><?php echo $total_clap; ?></span>
			拍手人数：<span class="clap_count"><?php echo $wp_list_table->total_unique_items(); ?></span>
			<div class="mwc-clap-table">
				<form action="" method="POST">
					<input type="hidden" name="mwc_action" value="delete" />
					<?php $wp_list_table->display(); ?>
				</form>
			</div><br class="clear" />
		</div>
		<?php

		// <form method="post">
		// <input type="hidden" name="page" value="example_list_table" />
		//  $exampleListTable->search_box('search', 'search_id');
		// </form>
	}

	///////////////////////////////////////
	/* 拍手ページ一覧 */
	///////////////////////////////////////
	public function mwc_id_list() {
		$wp_list_table = new MWC_ID_List_Table();

		$cog = array();

		// アイキャッチ表示
		if (isset($_GET['eyecatch'])) {
			$eyecatch = esc_attr($_GET['eyecatch']);
			$cog['list_id_eyecatch'] = $eyecatch;
		} else {
			$eyecatch = $this->get_option('list_id_eyecatch');
		}
		if (!empty($eyecatch)) {
			$wp_list_table->eyecatch_view = true;
		}

		// 記事ID表示
		if (isset($_GET['view_post_id'])) {
			$view_post_id = esc_attr($_GET['view_post_id']);
			$cog['list_id_view_post_id'] = $view_post_id;
		} else {
			$view_post_id = $this->get_option('list_id_view_post_id');
		}
		if (!empty($view_post_id)) {
			$wp_list_table->view_post_id = true;
		}

		// 表示設定保存
		if (!empty($cog)) {
			update_option('mwc_config', array_merge($this->pnop, $cog));
		}

		$sql = "SELECT *".
						" FROM " . $this->prefix. MWC_DB_TABLE_ID;

		$wp_list_table->query = $sql;
		$wp_list_table->prepare_items();

		?>
		<div class="wrap">
			<h2>拍手ページ一覧</h2>
			<form action="" method="get" name="mwc-clap-table-tool">
				<input type="hidden" name="page" value="mwc_id_list" />
				<ul class="mwc-clap-table-tool">
					<li>
						<input type="hidden" name="eyecatch" value="0" />
						<label><input type="checkbox" name="eyecatch" value="1"<?php checked($eyecatch, 1); ?> /> アイキャッチ画像を表示する</label>
					</li>
					<li>
						<input type="hidden" name="view_post_id" value="0" />
						<label><input type="checkbox" name="view_post_id" value="1"<?php checked($view_post_id, 1); ?> /> 記事IDを表示する</label>
					</li>
				</ul>
			</form>
			<hr>
			<div class="mwc-id-table">
				<?php $wp_list_table->display(); ?>
			</div>
		</div>
		<?php
	}
}