<?php
new MaroyakaWebClapCron();

class MaroyakaWebClapCron extends MaroyakaWebClap {

	function __construct() {
		parent::__construct();
		add_action( MWC_CRON_HOOK, array( $this, 'mail_clap_report' ) );
	}

	///////////////////////////////////////
	/* cron設定 */
	///////////////////////////////////////
	public static function add_schedule_event( $clear = false ) {
		if ( wp_next_scheduled( MWC_CRON_HOOK ) === false ) {
			if ( $clear ) {
				wp_clear_scheduled_hook(MWC_CRON_HOOK);
			}
			$now = new DateTime( date_i18n( 'Y-m-d' ), new DateTimeZone('Asia/Tokyo'));
			wp_schedule_event( $now->modify('+1 days')->getTimestamp(), 'daily', MWC_CRON_HOOK );
		}
	}

	///////////////////////////////////////
	/* 拍手レポート */
	///////////////////////////////////////
	public function mail_clap_report() {
		if ( $this->get_option( 'mail_clap_report' ) != 1 ) return;

		$prefix = MaroyakaWebClap::get_prefix();

		$stime = strtotime( date_i18n( 'Y-m-d' ). ' -1 day' );
		$sdate = date_i18n( 'Y-m-d', $stime );

		$sql = "SELECT *".
						" FROM " . $prefix. MWC_DB_TABLE_CLAP. " AS cl".
						" WHERE cl.timestamp >= '". $sdate. " 00:00:00'".
						" ORDER BY cl.id DESC";

		$sql = "SELECT *".
						" FROM (". $sql. ") AS gcl".
						" LEFT JOIN ". $prefix. MWC_DB_TABLE_MESSAGES. " AS ms".
							" ON gcl.id = ms.clap_id".
						" LEFT JOIN ". $prefix. MWC_DB_TABLE_ID. " AS cid".
							" ON gcl.post_id = cid.post_id";

		$clap_list = $this->db->get_results( $sql );
		$clap_total = count( $clap_list );

		if ( count( $clap_list ) > 0 ) {

			$clap_total = 0;
			$msg_total = 0;
			$report = array();
			foreach ( $clap_list as $clap ) {
				$clap_total += 1;
				$report[$clap->post_id]['count'] += 1;
				if ( ! isset( $report[$clap->post_id]['label'] ) )
					$report[$clap->post_id]['label'] = $clap->label;

				if ( ! empty( $clap->set_phrases ) )
					$report[$clap->post_id]['msg'][$clap->ip]['set_phrases'][] = $clap->set_phrases;
				if ( ! empty( $clap->message ) )
					$report[$clap->post_id]['msg'][$clap->ip]['comment'][] = $clap->message;
				if ( ! empty( $clap->name ) )
					$report[$clap->post_id]['msg'][$clap->ip]['name'] = $clap->name;

				if ( ! empty( $clap->set_phrases ) || ! empty( $clap->message ) || ! empty( $clap->name ) ) 
					$msg_total++;
			}

			// $sort = array();
			// foreach ( $report as $key => $value ) {
			// 	$sort[$key] = $value['count'];
			// }
			// array_multisort($sort, SORT_DESC, $report);
			usort($report, function ($a, $b) {
				return $b['count'] - $a['count'];
			});

			$to = $this->get_option( 'mailaddress', get_option( 'admin_email' ) );
			$subject = date_i18n( 'Y/m/d' ). '　WEB拍手レポート（' . $clap_total . '回'. ( ( count($msg_total) > 0 ) ? '・※'. $msg_total : '' ). '）';
			$body = "下記の内容で拍手がありました。\n".
								"=====================================\n";

			foreach ( $report as $rep ) {
				$body .= $rep['label']. "：". $rep['count']. "回\n";
				if ( ! empty( $rep['msg'] ) ) {
					foreach ( $rep['msg'] as $ip => $msg ) {
						$body .= "---\n";
						if ( ! empty( $msg['set_phrases'] ) ) {
							foreach ( $msg['set_phrases'] as $set_phrases ) {
								$body .= "【" . $set_phrases. "】";
							}
						}
						if ( ! empty( $msg['comment'] ) ) {
							foreach ( $msg['comment'] as $message ) {
								$body .= $message;
							}
						}
						if ( ! empty( $msg['name'] ) ) {
							$body .= " by " . $msg['name'];
						}
						$body .= "\n";
					}
				}
				$body .= "=====================================\n";
			}

			$body .= "集計対象日：". date_i18n( 'Y/m/d H:i', $stime ). "\n";
			wp_mail( $to, $subject, $body );
		}
	}
}